@@ -22,6 +22,14 @@
 
 #include <QTest>
 
+void DavItemFetchJobTest::initTestCase()
+{
+    // To avoid a runtime dependency on klauncher
+    qputenv("KDE_FORK_SLAVES", "yes");
+    // To let ctest exit, we shouldn't start kio_http_cache_cleaner
+    qputenv("KIO_DISABLE_CACHE_CLEANER", "yes");
+}
+
 void DavItemFetchJobTest::runSuccessfullTest()
 {
     FakeServer fakeServer;
