@@ -139,7 +139,7 @@ bool FakeServer::isAllScenarioDone() const
 {
     QMutexLocker locker(&m_mutex);
 
-    foreach (const QList<QByteArray> &scenario, m_scenarios) {
+    for (const QList<QByteArray> &scenario : qAsConst(m_scenarios)) {
         if (!scenario.isEmpty()) {
             return false;
         }
