@@ -1,19 +1,18 @@
 /*
     Copyright (c) 2009 Grégory Oestreicher <greg@kamago.net>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+    This program is free software; you can redistribute it and/or modify it
+    under the terms of the GNU Library General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or (at your
+    option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
+    This program is distributed in the hope that it will be useful, but WITHOUT
+    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
+    License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include "davcollection.h"
@@ -24,41 +23,24 @@
 
 using namespace KDAV;
 
-class DavCollectionPrivate
+class DavCollectionPrivate : public QSharedData
 {
 public:
-    DavCollectionPrivate(DavCollection *qPtr) : q(qPtr)
-    {
-    }
-
-    void fillFrom(const DavCollectionPrivate &other);
-
-    DavCollection *q;
+    DavCollection::ContentTypes mContentTypes;
     QString mCTag;
     DavUrl mUrl;
     QString mDisplayName;
     QColor mColor;
-    DavCollection::ContentTypes mContentTypes;
     Privileges mPrivileges;
 };
 
-void DavCollectionPrivate::fillFrom(const DavCollectionPrivate &other)
-{
-    mCTag = other.mCTag;
-    mUrl = other.mUrl;
-    mDisplayName = other.mDisplayName;
-    mColor = other.mColor;
-    mContentTypes = other.mContentTypes;
-    mPrivileges = other.mPrivileges;
-}
-
 DavCollection::DavCollection()
-    : d(std::unique_ptr<DavCollectionPrivate>(new DavCollectionPrivate(this)))
+    : d(new DavCollectionPrivate)
 {
 }
 
 DavCollection::DavCollection(const DavUrl &url, const QString &displayName, ContentTypes contentTypes)
-    : d(std::unique_ptr<DavCollectionPrivate>(new DavCollectionPrivate(this)))
+    : d(new DavCollectionPrivate)
 {
     d->mUrl = url;
     d->mDisplayName = displayName;
@@ -66,21 +48,9 @@ DavCollection::DavCollection(const DavUrl &url, const QString &displayName, Cont
     d->mPrivileges = KDAV::All;
 }
 
-DavCollection::DavCollection(const DavCollection &other)
-    : d(std::unique_ptr<DavCollectionPrivate>(new DavCollectionPrivate(this)))
-{
-    d->fillFrom(*other.d.get());
-}
-
-DavCollection &DavCollection::operator=(const DavCollection &other)
-{
-    d->fillFrom(*other.d.get());
-    return *this;
-}
-
-DavCollection::~DavCollection()
-{
-}
+DavCollection::DavCollection(const DavCollection &other) = default;
+DavCollection &DavCollection::operator=(const DavCollection &other) = default;
+DavCollection::~DavCollection() = default;
 
 void DavCollection::setCTag(const QString &ctag)
 {
