@@ -1,19 +1,18 @@
 /*
     Copyright (c) 2009 Grégory Oestreicher <greg@kamago.net>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+    This program is free software; you can redistribute it and/or modify it
+    under the terms of the GNU Library General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or (at your
+    option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
+    This program is distributed in the hope that it will be useful, but WITHOUT
+    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
+    License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #ifndef KDAV_DAVCOLLECTION_H
@@ -23,23 +22,19 @@
 
 #include "enums.h"
 
-#include <memory>
-
-#include <QVector>
+#include <QSharedDataPointer>
 #include <QString>
+#include <QVector>
 
 class QColor;
 
 class DavCollectionPrivate;
 
-namespace KDAV
-{
-    class DavUrl;
+namespace KDAV {
+class DavUrl;
 }
 
-namespace KDAV
-{
-
+namespace KDAV {
 /**
  * @short A helper class to store information about DAV collection.
  *
@@ -95,7 +90,7 @@ public:
      * Returns this collection CTag. The returned value will be empty
      * if no CTag was found.
      */
-    QString CTag() const;
+    Q_REQUIRED_RESULT QString CTag() const;
 
     /**
      * Sets the @p url that identifies the collection.
@@ -105,7 +100,7 @@ public:
     /**
      * Returns the url that identifies the collection.
      */
-    DavUrl url() const;
+    Q_REQUIRED_RESULT DavUrl url() const;
 
     /**
      * Sets the display @p name of the collection.
@@ -115,7 +110,7 @@ public:
     /**
      * Returns the display name of the collection.
      */
-    QString displayName() const;
+    Q_REQUIRED_RESULT QString displayName() const;
 
     /**
      * Sets the color for this collection
@@ -126,7 +121,7 @@ public:
      * Return the color of the collection, or an empty string if
      * none was provided by the backend.
      */
-    QColor color() const;
+    Q_REQUIRED_RESULT QColor color() const;
 
     /**
      * Sets the possible content @p types of the collection.
@@ -136,7 +131,7 @@ public:
     /**
      * Returns the possible content types of the collection.
      */
-    ContentTypes contentTypes() const;
+    Q_REQUIRED_RESULT ContentTypes contentTypes() const;
 
     /**
      * Sets the privileges on this collection.
@@ -146,12 +141,11 @@ public:
     /**
      * Returns the privileges on this collection.
      */
-    Privileges privileges() const;
+    Q_REQUIRED_RESULT Privileges privileges() const;
 
 private:
-    std::unique_ptr<DavCollectionPrivate> d;
+    QSharedDataPointer<DavCollectionPrivate> d;
 };
-
 }
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KDAV::DavCollection::ContentTypes)
