@@ -1,27 +1,27 @@
 /*
     Copyright (c) 2010 Tobias Koenig <tokoe@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+    This program is free software; you can redistribute it and/or modify it
+    under the terms of the GNU Library General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or (at your
+    option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
+    This program is distributed in the hope that it will be useful, but WITHOUT
+    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
+    License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include "davcollectionsfetchjob.h"
+#include "davjobbase_p.h"
 
-#include "davmanager.h"
+#include "davmanager_p.h"
 #include "davprincipalhomesetsfetchjob.h"
-#include "davprotocolbase.h"
-#include "utils.h"
+#include "davprotocolbase_p.h"
+#include "utils_p.h"
 #include "daverror.h"
 
 #include "libkdav_debug.h"
@@ -34,39 +34,53 @@
 
 using namespace KDAV;
 
-DavCollectionsFetchJob::DavCollectionsFetchJob(const DavUrl &url, QObject *parent)
-    : DavJobBase(parent)
-    , mUrl(url)
-    , mSubJobCount(0)
+namespace KDAV {
+class DavCollectionsFetchJobPrivate : public DavJobBasePrivate
 {
+public:
+    DavUrl mUrl;
+    DavCollection::List mCollections;
+    uint mSubJobCount = 0;
+};
+}
+
+DavCollectionsFetchJob::DavCollectionsFetchJob(const DavUrl &url, QObject *parent)
+    : DavJobBase(new DavCollectionsFetchJobPrivate, parent)
+{
+    Q_D(DavCollectionsFetchJob);
+    d->mUrl = url;
 }
 
 void DavCollectionsFetchJob::start()
 {
-    if (DavManager::self()->davProtocol(mUrl.protocol())->supportsPrincipals()) {
-        DavPrincipalHomeSetsFetchJob *job = new DavPrincipalHomeSetsFetchJob(mUrl);
+    Q_D(DavCollectionsFetchJob);
+    if (DavManager::davProtocol(d->mUrl.protocol())->supportsPrincipals()) {
+        DavPrincipalHomeSetsFetchJob *job = new DavPrincipalHomeSetsFetchJob(d->mUrl);
         connect(job, &DavPrincipalHomeSetsFetchJob::result, this, &DavCollectionsFetchJob::principalFetchFinished);
         job->start();
     } else {
-        doCollectionsFetch(mUrl.url());
+        doCollectionsFetch(d->mUrl.url());
     }
 }
 
 DavCollection::List DavCollectionsFetchJob::collections() const
 {
-    return mCollections;
+    Q_D(const DavCollectionsFetchJob);
+    return d->mCollections;
 }
 
 DavUrl DavCollectionsFetchJob::davUrl() const
 {
-    return mUrl;
+    Q_D(const DavCollectionsFetchJob);
+    return d->mUrl;
 }
 
 void DavCollectionsFetchJob::doCollectionsFetch(const QUrl &url)
 {
-    ++mSubJobCount;
+    Q_D(DavCollectionsFetchJob);
+    ++d->mSubJobCount;
 
-    const QDomDocument collectionQuery = DavManager::self()->davProtocol(mUrl.protocol())->collectionsQuery()->buildQuery();
+    const QDomDocument collectionQuery = DavManager::davProtocol(d->mUrl.protocol())->collectionsQuery()->buildQuery();
 
     KIO::DavJob *job = DavManager::self()->createPropFindJob(url, collectionQuery);
     connect(job, &KIO::DavJob::result, this, &DavCollectionsFetchJob::collectionsFetchFinished);
@@ -75,6 +89,7 @@ void DavCollectionsFetchJob::doCollectionsFetch(const QUrl &url)
 
 void DavCollectionsFetchJob::principalFetchFinished(KJob *job)
 {
+    Q_D(DavCollectionsFetchJob);
     const DavPrincipalHomeSetsFetchJob *davJob = qobject_cast<DavPrincipalHomeSetsFetchJob *>(job);
 
     if (davJob->error()) {
@@ -82,7 +97,7 @@ void DavCollectionsFetchJob::principalFetchFinished(KJob *job)
             // If we have a HTTP response code then this may mean that
             // the URL was not a principal URL. Retry as if it were a calendar URL.
             qCDebug(KDAV_LOG) << job->errorText();
-            doCollectionsFetch(mUrl.url());
+            doCollectionsFetch(d->mUrl.url());
         } else {
             // Just give up here.
             setDavError(davJob->davError());
@@ -99,12 +114,12 @@ void DavCollectionsFetchJob::principalFetchFinished(KJob *job)
 
     if (homeSets.isEmpty()) {
         // Same as above, retry as if it were a calendar URL.
-        doCollectionsFetch(mUrl.url());
+        doCollectionsFetch(d->mUrl.url());
         return;
     }
 
     for (const QString &homeSet : homeSets) {
-        QUrl url = mUrl.url();
+        QUrl url = d->mUrl.url();
 
         if (homeSet.startsWith(QLatin1Char('/'))) {
             // homeSet is only a path, use request url to complete
@@ -123,6 +138,7 @@ void DavCollectionsFetchJob::principalFetchFinished(KJob *job)
 
 void DavCollectionsFetchJob::collectionsFetchFinished(KJob *job)
 {
+    Q_D(DavCollectionsFetchJob);
     KIO::DavJob *davJob = qobject_cast<KIO::DavJob *>(job);
     const QString responseCodeStr = davJob->queryMetaData(QStringLiteral("responsecode"));
     const int responseCode = responseCodeStr.isEmpty()
@@ -131,12 +147,12 @@ void DavCollectionsFetchJob::collectionsFetchFinished(KJob *job)
 
     // KIO::DavJob does not set error() even if the HTTP status code is a 4xx or a 5xx
     if (davJob->error() || (responseCode >= 400 && responseCode < 600)) {
-        if (davJob->url() != mUrl.url()) {
+        if (davJob->url() != d->mUrl.url()) {
             // Retry as if the initial URL was a calendar URL.
             // We can end up here when retrieving a homeset on
             // which a PROPFIND resulted in an error
-            doCollectionsFetch(mUrl.url());
-            --mSubJobCount;
+            doCollectionsFetch(d->mUrl.url());
+            --d->mSubJobCount;
             return;
         }
 
@@ -147,7 +163,7 @@ void DavCollectionsFetchJob::collectionsFetchFinished(KJob *job)
         setErrorTextFromDavError();
     } else {
         // For use in the collectionDiscovered() signal
-        QUrl _jobUrl = mUrl.url();
+        QUrl _jobUrl = d->mUrl.url();
         _jobUrl.setUserInfo(QString());
         const QString jobUrl = _jobUrl.toDisplayString();
 
@@ -172,7 +188,7 @@ void DavCollectionsFetchJob::collectionsFetchFinished(KJob *job)
             return;
         }
 
-        xquery.setQuery(DavManager::self()->davProtocol(mUrl.protocol())->collectionsXQuery());
+        xquery.setQuery(DavManager::davProtocol(d->mUrl.protocol())->collectionsXQuery());
         if (!xquery.isValid()) {
             setError(ERR_COLLECTIONFETCH_XQUERY_INVALID);
             setErrorTextFromDavError();
@@ -275,7 +291,7 @@ void DavCollectionsFetchJob::collectionsFetchFinished(KJob *job)
 
                 // don't add this resource if it has already been detected
                 bool alreadySeen = false;
-                for (const DavCollection &seen : qAsConst(mCollections)) {
+                for (const DavCollection &seen : qAsConst(d->mCollections)) {
                     if (seen.url().toDisplayString() == url.toDisplayString()) {
                         alreadySeen = true;
                     }
@@ -315,11 +331,11 @@ void DavCollectionsFetchJob::collectionsFetchFinished(KJob *job)
                 }
 
                 // extract allowed content types
-                const DavCollection::ContentTypes contentTypes = DavManager::self()->davProtocol(mUrl.protocol())->collectionContentTypes(propstatElement);
+                const DavCollection::ContentTypes contentTypes = DavManager::davProtocol(d->mUrl.protocol())->collectionContentTypes(propstatElement);
 
                 auto _url = url;
-                _url.setUserInfo(mUrl.url().userInfo());
-                DavCollection collection(DavUrl(_url, mUrl.protocol()), displayName, contentTypes);
+                _url.setUserInfo(d->mUrl.url().userInfo());
+                DavCollection collection(DavUrl(_url, d->mUrl.protocol()), displayName, contentTypes);
 
                 collection.setCTag(CTag);
                 if (color.isValid()) {
@@ -337,8 +353,8 @@ void DavCollectionsFetchJob::collectionsFetchFinished(KJob *job)
                 }
 
                 qCDebug(KDAV_LOG) << url.toDisplayString() << "PRIVS: " << collection.privileges();
-                mCollections << collection;
-                Q_EMIT collectionDiscovered(mUrl.protocol(), url.toDisplayString(), jobUrl);
+                d->mCollections << collection;
+                Q_EMIT collectionDiscovered(d->mUrl.protocol(), url.toDisplayString(), jobUrl);
 
                 responseElement = Utils::nextSiblingElementNS(responseElement, QStringLiteral("DAV:"), QStringLiteral("response"));
             }
@@ -350,7 +366,8 @@ void DavCollectionsFetchJob::collectionsFetchFinished(KJob *job)
 
 void DavCollectionsFetchJob::subjobFinished()
 {
-    if (--mSubJobCount == 0) {
+    Q_D(DavCollectionsFetchJob);
+    if (--d->mSubJobCount == 0) {
         emitResult();
     }
 }
