@@ -1,19 +1,18 @@
 /*
     Copyright (c) 2010 Tobias Koenig <tokoe@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+    This program is free software; you can redistribute it and/or modify it
+    under the terms of the GNU Library General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or (at your
+    option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
+    This program is distributed in the hope that it will be useful, but WITHOUT
+    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
+    License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include "davcollectionsmultifetchjob.h"
@@ -22,20 +21,33 @@
 
 using namespace KDAV;
 
+namespace KDAV {
+class DavCollectionsMultiFetchJobPrivate
+{
+public:
+    DavUrl::List mUrls;
+    DavCollection::List mCollections;
+    int mSubJobCount = -1;
+};
+}
+
 DavCollectionsMultiFetchJob::DavCollectionsMultiFetchJob(const DavUrl::List &urls, QObject *parent)
     : KJob(parent)
-    , mUrls(urls)
-    , mSubJobCount(urls.size())
+    , d(new DavCollectionsMultiFetchJobPrivate)
 {
+    d->mUrls = urls;
+    d->mSubJobCount = urls.size();
 }
 
+DavCollectionsMultiFetchJob::~DavCollectionsMultiFetchJob() = default;
+
 void DavCollectionsMultiFetchJob::start()
 {
-    if (mUrls.isEmpty()) {
+    if (d->mUrls.isEmpty()) {
         emitResult();
     }
 
-    for (const DavUrl &url : qAsConst(mUrls)) {
+    for (const DavUrl &url : qAsConst(d->mUrls)) {
         DavCollectionsFetchJob *job = new DavCollectionsFetchJob(url, this);
         connect(job, &DavCollectionsFetchJob::result, this, &DavCollectionsMultiFetchJob::davJobFinished);
         connect(job, &DavCollectionsFetchJob::collectionDiscovered, this, &DavCollectionsMultiFetchJob::collectionDiscovered);
@@ -45,7 +57,7 @@ void DavCollectionsMultiFetchJob::start()
 
 DavCollection::List DavCollectionsMultiFetchJob::collections() const
 {
-    return mCollections;
+    return d->mCollections;
 }
 
 void DavCollectionsMultiFetchJob::davJobFinished(KJob *job)
@@ -56,10 +68,10 @@ void DavCollectionsMultiFetchJob::davJobFinished(KJob *job)
         setError(job->error());
         setErrorText(job->errorText());
     } else {
-        mCollections << fetchJob->collections();
+        d->mCollections << fetchJob->collections();
     }
 
-    if (--mSubJobCount == 0) {
+    if (--d->mSubJobCount == 0) {
         emitResult();
     }
 }
