@@ -1,19 +1,18 @@
 /*
     Copyright (c) 2009 Grégory Oestreicher <greg@kamago.net>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+    This program is free software; you can redistribute it and/or modify it
+    under the terms of the GNU Library General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or (at your
+    option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
+    This program is distributed in the hope that it will be useful, but WITHOUT
+    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
+    License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #ifndef KDAV_DAVITEM_H
@@ -21,24 +20,19 @@
 
 #include "kpimkdav_export.h"
 
-#include <memory>
-
-#include <QtCore/QByteArray>
-#include <QtCore/QDataStream>
-#include <QtCore/QString>
-#include <QtCore/QVector>
-
+#include <QByteArray>
+#include <QDataStream>
+#include <QSharedDataPointer>
+#include <QString>
+#include <QVector>
 
 class DavItemPrivate;
 
-namespace KDAV
-{
-    class DavUrl;
+namespace KDAV {
+class DavUrl;
 }
 
-namespace KDAV
-{
-
+namespace KDAV {
 /**
  * @short A helper class to store information about DAV resources.
  *
@@ -84,7 +78,7 @@ public:
     /**
      * Returns the url that identifies the item.
      */
-    DavUrl url() const;
+    Q_REQUIRED_RESULT DavUrl url() const;
 
     /**
      * Sets the content @p type of the item.
@@ -94,7 +88,7 @@ public:
     /**
      * Returns the content type of the item.
      */
-    QString contentType() const;
+    Q_REQUIRED_RESULT QString contentType() const;
 
     /**
      * Sets the raw content @p data of the item.
@@ -104,7 +98,7 @@ public:
     /**
      * Returns the raw content data of the item.
      */
-    QByteArray data() const;
+    Q_REQUIRED_RESULT QByteArray data() const;
 
     /**
      * Sets the @p etag of the item.
@@ -114,15 +108,14 @@ public:
     /**
      * Returns the etag of the item.
      */
-    QString etag() const;
+    Q_REQUIRED_RESULT QString etag() const;
 
 private:
-    std::unique_ptr<DavItemPrivate> d;
+    QSharedDataPointer<DavItemPrivate> d;
 };
 
 KPIMKDAV_EXPORT QDataStream &operator<<(QDataStream &out, const DavItem &item);
 KPIMKDAV_EXPORT QDataStream &operator>>(QDataStream &in, DavItem &item);
-
 }
 
 Q_DECLARE_TYPEINFO(KDAV::DavItem, Q_MOVABLE_TYPE);
