@@ -1,19 +1,18 @@
 /*
     Copyright (c) 2010 Tobias Koenig <tokoe@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+    This program is free software; you can redistribute it and/or modify it
+    under the terms of the GNU Library General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or (at your
+    option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
+    This program is distributed in the hope that it will be useful, but WITHOUT
+    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
+    License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #ifndef KDAV_DAVITEMFETCHJOB_H
@@ -25,8 +24,8 @@
 #include "davjobbase.h"
 #include "davurl.h"
 
-namespace KDAV
-{
+namespace KDAV {
+class DavItemFetchJobPrivate;
 
 /**
  * @short A job that fetches a DAV item from the DAV server.
@@ -42,7 +41,7 @@ public:
      * @param item The item that shall be fetched.
      * @param parent The parent object.
      */
-    DavItemFetchJob(const DavItem &item, QObject *parent = nullptr);
+    explicit DavItemFetchJob(const DavItem &item, QObject *parent = nullptr);
 
     /**
      * Starts the job.
@@ -52,14 +51,12 @@ public:
     /**
      * Returns the fetched item including current etag information.
      */
-    DavItem item() const;
+    Q_REQUIRED_RESULT DavItem item() const;
 
 private:
     void davJobFinished(KJob *);
-    DavUrl mUrl;
-    DavItem mItem;
+    Q_DECLARE_PRIVATE(DavItemFetchJob)
 };
-
 }
 
 #endif
