@@ -1,19 +1,18 @@
 /*
     Copyright (c) 2010 Tobias Koenig <tokoe@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+    This program is free software; you can redistribute it and/or modify it
+    under the terms of the GNU Library General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or (at your
+    option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
+    This program is distributed in the hope that it will be useful, but WITHOUT
+    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
+    License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #ifndef KDAV_DAVITEMMODIFYJOB_H
@@ -26,6 +25,8 @@
 #include "davurl.h"
 
 namespace KDAV {
+class DavItemModifyJobPrivate;
+
 /**
  * @short A job that modifies a DAV item on the DAV server.
  */
@@ -40,7 +41,7 @@ public:
      * @param item The item that shall be modified.
      * @param parent The parent object.
      */
-    DavItemModifyJob(const DavItem &item, QObject *parent = nullptr);
+    explicit DavItemModifyJob(const DavItem &item, QObject *parent = nullptr);
 
     /**
      * Starts the job.
@@ -68,9 +69,8 @@ private:
     void davJobFinished(KJob *);
     void itemRefreshed(KJob *);
     void conflictingItemFetched(KJob *);
-    DavItem mItem;
-    DavItem mFreshItem;
-    int mFreshResponseCode;
+
+    Q_DECLARE_PRIVATE(DavItemModifyJob)
 };
 }
 
