@@ -2,19 +2,18 @@
     Copyright (c) 2010 Grégory Oestreicher <greg@kamago.net>
     Based on DavItemsListJob which is copyright (c) 2010 Tobias Koenig <tokoe@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+    This program is free software; you can redistribute it and/or modify it
+    under the terms of the GNU Library General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or (at your
+    option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
+    This program is distributed in the hope that it will be useful, but WITHOUT
+    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
+    License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #ifndef KDAV_DAVITEMSFETCHJOB_H
@@ -30,6 +29,8 @@
 #include <QStringList>
 
 namespace KDAV {
+class DavItemsFetchJobPrivate;
+
 /**
  * @short A job that fetches a list of items from a DAV server using a multiget query.
  */
@@ -64,9 +65,7 @@ public:
 
 private:
     void davJobFinished(KJob *);
-    DavUrl mCollectionUrl;
-    QStringList mUrls;
-    QMap<QString, DavItem> mItems;
+    Q_DECLARE_PRIVATE(DavItemsFetchJob)
 };
 }
 
