@@ -1,31 +1,40 @@
 /*
-    SPDX-FileCopyrightText: 2009 Grégory Oestreicher <greg@kamago.net>
+    Copyright (c) 2009 Grégory Oestreicher <greg@kamago.net>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This program is free software; you can redistribute it and/or modify it
+    under the terms of the GNU Library General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or (at your
+    option) any later version.
+
+    This program is distributed in the hope that it will be useful, but WITHOUT
+    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
+    License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #ifndef KDAV_DAVPROTOCOLBASE_H
 #define KDAV_DAVPROTOCOLBASE_H
 
-#include "kdav_export.h"
+#include "kpimkdav_export.h"
 
 #include "davcollection.h"
 
-#include <QDomDocument>
 #include <QMap>
+#include <QDomDocument>
+#include <QSharedPointer>
 #include <QVariant>
-#include <memory>
 
-namespace KDAV
-{
-/*!
- * \internal
- * \brief Base class for XML query builders
+namespace KDAV {
+/**
+ * @short Base class for XML query builders
  */
 class XMLQueryBuilder
 {
 public:
-    typedef std::shared_ptr<XMLQueryBuilder> Ptr;
+    typedef QSharedPointer<XMLQueryBuilder> Ptr;
 
     virtual ~XMLQueryBuilder();
 
@@ -39,83 +48,82 @@ private:
     QMap<QString, QVariant> mParameters;
 };
 
-/*!
- * \internal
- * \brief Base class for various DAV groupware dialects.
+/**
+ * @short Base class for various DAV groupware dialects.
  *
  * This class provides an interface to query the DAV dialect
  * specific features and abstract them.
  *
  * The functionality is implemented in:
- *   - CaldavProtocol
- *   - CarddavProtocol
- *   - GroupdavProtocol
+ *   @li CaldavProtocol
+ *   @li CarddavProtocol
+ *   @li GroupdavProtocol
  */
 class DavProtocolBase
 {
 public:
-    /*!
-     * Destroys the DAV protocol base.
+    /**
+     * Destroys the dav protocol base.
      */
     virtual ~DavProtocolBase();
 
-    /*!
-     * Returns whether the DAV protocol dialect supports principal
+    /**
+     * Returns whether the dav protocol dialect supports principal
      * queries. If true, it must return the home set it provides
      * access to with principalHomeSet() and the home set namespace
      * with principalHomeSetNS();
      */
     virtual bool supportsPrincipals() const = 0;
 
-    /*!
-     * Returns whether the DAV protocol dialect supports the REPORT
+    /**
+     * Returns whether the dav protocol dialect supports the REPORT
      * command to query all resources of a collection.
      * If not, PROPFIND command will be used instead.
      */
     virtual bool useReport() const = 0;
 
-    /*!
-     * Returns whether the DAV protocol dialect supports the MULTIGET command.
+    /**
+     * Returns whether the dav protocol dialect supports the MULTIGET command.
      *
-     * If MULTIGET is supported, the content of all DAV resources
-     * can be fetched in Akonadi::ResourceBase::retrieveItems() already and
-     * there is no need to call Akonadi::ResourceBase::retrieveItem() for every single
-     * DAV resource.
+     * If MULTIGET is supported, the content of all dav resources
+     * can be fetched in ResourceBase::retrieveItems() already and
+     * there is no need to call ResourceBase::retrieveItem() for every single
+     * dav resource.
      *
      * Protocols that have MULTIGET capabilities must inherit from
      * DavMultigetProtocol instead of this class.
      */
     virtual bool useMultiget() const = 0;
 
-    /*!
+    /**
      * Returns the home set that this protocol supports.
      */
     virtual QString principalHomeSet() const;
 
-    /*!
+    /**
      * Returns the namespace of the home set.
      */
     virtual QString principalHomeSetNS() const;
 
-    /*!
+    /**
      * Returns the XML document that represents the DAV query to
      * list all available DAV collections.
      */
     virtual XMLQueryBuilder::Ptr collectionsQuery() const = 0;
 
-    /*!
-     * Returns @c true if the given <prop> element of a multistatus response contains a
-     * valid collection for this protocol.
+    /**
+     * Returns the XQuery string that filters out the relevant XML elements
+     * from the result returned by the query that is provided by collectionQuery().
      */
-    virtual bool containsCollection(const QDomElement &propElem) const = 0;
+    virtual QString collectionsXQuery() const = 0;
 
-    /*!
+    /**
      * Returns a list of XML documents that represent DAV queries to
      * list all available DAV resources inside a specific DAV collection.
      */
-    virtual QList<XMLQueryBuilder::Ptr> itemsQueries() const = 0;
+    virtual QVector<XMLQueryBuilder::Ptr> itemsQueries() const = 0;
 
-    /*!
+    /**
      * Returns the possible content types for the collection that
      * is described by the passed @p propstat element of a PROPFIND result.
      */
